@@ -35,6 +35,8 @@
 #include "zoom-region-private.h"
 #include "GNOME_Magnifier.h"
 
+#define MAG_WINDOW_OVERRIDE_REDIRECT
+
 static GObjectClass *parent_class = NULL;
 
 enum {
@@ -131,7 +133,8 @@ magnifier_realize (GtkWidget *widget)
 	GdkDisplay *target_display = gdk_drawable_get_display (widget->window);
 	
 	static gboolean initialized = FALSE;
-	
+
+#ifndef MAG_WINDOW_OVERRIDE_REDIRECT	
 	if (!initialized) {
 		wm_window_protocols[0] = gdk_x11_get_xatom_by_name_for_display (target_display,
 										"WM_DELETE_WINDOW");
@@ -161,14 +164,14 @@ magnifier_realize (GtkWidget *widget)
 				 XA_ATOM, 32, PropModeReplace,
 				 (guchar *)wm_type_atoms,
 				 1);
-
+#else
+#endif
 	/* TODO: make sure this works/is reset if the DISPLAY 
 	 * (as well as the SCREEN) changes.
 	 */
 
 	XSetErrorHandler (magnifier_x_error_handler);
 
-	fprintf (stderr, "Realize complete.\n");
 }
 
 GdkWindow*
@@ -934,7 +937,11 @@ magnifier_init_window (Magnifier *magnifier)
 		g_object_connect (gtk_widget_new (gtk_window_get_type (),
 						  "user_data", NULL,
 						  "can_focus", FALSE,
+#ifdef MAG_WINDOW_OVERRIDE_REDIRECT
+						  "type", GTK_WINDOW_POPUP,
+#else
 						  "type", GTK_WINDOW_TOPLEVEL,
+#endif
 						  "title", "magnifier",
 						  "allow_grow", TRUE,
 						  "allow_shrink", TRUE,
@@ -943,7 +950,6 @@ magnifier_init_window (Magnifier *magnifier)
 				  "signal::realize", magnifier_realize, NULL,
 				  "signal::destroy", magnifier_exit, NULL,
 				  NULL);
-	gtk_window_set_decorated (GTK_WINDOW (magnifier->priv->w), FALSE);
 	magnifier->priv->canvas = gtk_fixed_new ();
 	gtk_container_add (GTK_CONTAINER (magnifier->priv->w),
 			   magnifier->priv->canvas);
